@@ -6,7 +6,7 @@
  */
 
 /*
- * Copyright 2009-2010 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009--2014 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -36,10 +36,12 @@
 #include <string.h>
 
 #include "oval_definitions_impl.h"
-#include "oval_collection_impl.h"
+#include "adt/oval_collection_impl.h"
 #include "oval_agent_api_impl.h"
 #include "common/debug_priv.h"
+#include "common/elements.h"
 #include "public/oval_version.h"
+#include "public/oval_schema_version.h"
 
 typedef struct oval_object {
 	struct oval_definition_model *model;
@@ -132,18 +134,22 @@ int oval_object_get_version(struct oval_object *object)
 
 oval_version_t oval_object_get_schema_version(struct oval_object *object)
 {
-	struct oval_generator *gen;
-	const char *ver_str;
-
 	__attribute__nonnull__(object);
 
 	if (object->model == NULL)
 		return OVAL_VERSION_INVALID;
+	return oval_definition_model_get_schema_version(object->model);
+}
 
-	gen = oval_definition_model_get_generator(object->model);
-	ver_str = oval_generator_get_schema_version(gen);
-
-	return oval_version_from_cstr(ver_str);
+oval_schema_version_t oval_object_get_platform_schema_version(struct oval_object *object)
+{
+	__attribute__nonnull__(object);
+	if (object->model == NULL) {
+		return OVAL_SCHEMA_VERSION_INVALID;
+	}
+	oval_family_t family = oval_object_get_family(object);
+	const char *platform = oval_family_get_text(family);
+	return oval_definition_model_get_platform_schema_version(object->model, platform);
 }
 
 struct oval_object_content_iterator *oval_object_get_object_contents(struct
@@ -169,7 +175,7 @@ struct oval_object *oval_object_new(struct oval_definition_model *model, const c
 	__attribute__nonnull__(model);
 	oval_object_t *object;
 
-	object = (oval_object_t *) oscap_alloc(sizeof(oval_object_t));
+	object = (oval_object_t *) malloc(sizeof(oval_object_t));
 	if (object == NULL)
 		return NULL;
 
@@ -240,11 +246,11 @@ void oval_object_free(struct oval_object *object)
 		return;
 
 	if (object->comment != NULL)
-		oscap_free(object->comment);
+		free(object->comment);
 	if (object->id != NULL)
-		oscap_free(object->id);
+		free(object->id);
 	oval_collection_free_items(object->behaviors, (oscap_destruct_func) oval_behavior_free);
-	oval_collection_free_items(object->notes, (oscap_destruct_func) oscap_free);
+	oval_collection_free_items(object->notes, (oscap_destruct_func) free);
 	oval_collection_free_items(object->object_content, (oscap_destruct_func) oval_object_content_free);
 
 	object->comment = NULL;
@@ -252,7 +258,7 @@ void oval_object_free(struct oval_object *object)
 	object->behaviors = NULL;
 	object->notes = NULL;
 	object->object_content = NULL;
-	oscap_free(object);
+	free(object);
 }
 
 void oval_object_set_subtype(struct oval_object *object, oval_subtype_t subtype)
@@ -271,7 +277,7 @@ void oval_object_set_comment(struct oval_object *object, char *comm)
 {
 	__attribute__nonnull__(object);
 	if (object->comment != NULL)
-		oscap_free(object->comment);
+		free(object->comment);
 	object->comment = (comm == NULL) ? NULL : oscap_strdup(comm);
 }
 
@@ -307,7 +313,7 @@ static void oval_note_consume(char *text, void *object)
 static int _oval_object_parse_notes(xmlTextReaderPtr reader, struct oval_parser_context *context, void *user)
 {
 	struct oval_object *object = (struct oval_object *)user;
-	return oval_parser_text_value(reader, context, &oval_note_consume, object);
+	return oscap_parser_text_value(reader, &oval_note_consume, object);
 }
 
 static void oval_behavior_consume(struct oval_behavior *behavior, void *object)
@@ -335,11 +341,11 @@ static int _oval_object_parse_tag(xmlTextReaderPtr reader, struct oval_parser_co
 	}
 
 	if (return_code != 0) {
-		dW("Parsing of <%s> terminated by an error at line %d.\n", tagname, xmlTextReaderGetParserLineNumber(reader));
+		dW("Parsing of <%s> terminated by an error at line %d.", tagname, xmlTextReaderGetParserLineNumber(reader));
 	}
 
-	oscap_free(tagname);
-	oscap_free(namespace);
+	free(tagname);
+	free(namespace);
 	return return_code;
 }
 
@@ -356,7 +362,7 @@ int oval_object_parse_tag(xmlTextReaderPtr reader, struct oval_parser_context *c
 
 	oval_subtype_t subtype = oval_subtype_parse(reader);
 	if ( subtype == OVAL_SUBTYPE_UNKNOWN) {
-		oscap_dlprintf(DBG_E,  "Unknown object %s.\n", id);
+		dE("Unknown object %s.", id);
 		ret = -1;
 		goto cleanup;
 	}
@@ -376,9 +382,9 @@ int oval_object_parse_tag(xmlTextReaderPtr reader, struct oval_parser_context *c
 	ret = oval_parser_parse_tag(reader, context, &_oval_object_parse_tag, object);
 
 cleanup:
-	oscap_free(id);
-	oscap_free(comm);
-	oscap_free(version);
+	free(id);
+	free(comm);
+	free(version);
 	return ret;
 }
 
@@ -389,7 +395,7 @@ xmlNode *oval_object_to_dom(struct oval_object *object, xmlDoc * doc, xmlNode *
 	/* skip unknown object */
 	oval_subtype_t subtype = oval_object_get_subtype(object);
         if ( subtype == OVAL_SUBTYPE_UNKNOWN ) {
-                oscap_dlprintf(DBG_E, "Unknown Object %s.\n", oval_object_get_id(object));
+                dE("Unknown Object %s.", oval_object_get_id(object));
                 return object_node;
         }
 
@@ -398,14 +404,10 @@ xmlNode *oval_object_to_dom(struct oval_object *object, xmlDoc * doc, xmlNode *
 	char object_name[strlen(subtype_text) + 8];
 	sprintf(object_name, "%s_object", subtype_text);
 
-	/* get family URI */
 	oval_family_t family = oval_object_get_family(object);
-	const char *family_text = oval_family_get_text(family);
-	char family_uri[strlen((const char *)OVAL_DEFINITIONS_NAMESPACE) + strlen(family_text) + 2];
-	sprintf(family_uri,"%s#%s", OVAL_DEFINITIONS_NAMESPACE, family_text);
 
 	/* search namespace & create child */
-	xmlNs *ns_family = xmlSearchNsByHref(doc, parent, BAD_CAST family_uri);
+	xmlNs *ns_family = oval_family_to_namespace(family, (const char *) OVAL_DEFINITIONS_NAMESPACE, doc, parent);
 	object_node = xmlNewTextChild(parent, ns_family, BAD_CAST object_name, NULL);
 
 	char *id = oval_object_get_id(object);
@@ -474,7 +476,7 @@ struct oval_object *oval_object_create_internal(struct oval_object *obj, char *s
 	new_obj_id[oid_len + sid_len + 1] = '\0';
 	new_obj = oval_object_clone2(obj->model, obj, new_obj_id);
 	new_obj->base_obj_ref = obj;
-	oscap_free(new_obj_id);
+	free(new_obj_id);
 
 	return new_obj;
 }
