@@ -28,9 +28,9 @@
 #include <pthread.h>
 #include <stdint.h>
 #include "generic/bitmap.h"
-#include "generic/pqueue.h"
 #include "generic/rbt/rbt.h"
 #include "_sexp-types.h"
+#include "_seap-packetq.h"
 #include "_sexp-parser.h"
 #include "_sexp-output.h"
 #include "_seap-command.h"
@@ -47,17 +47,16 @@ OSCAP_HIDDEN_START;
  */
 typedef struct {
         SEAP_msgid_t   next_id;
-        SEXP_t        *sexpbuf; /* S-exp buffer */
         SEXP_ostate_t *ostate; /* Output state */
         SEXP_pstate_t *pstate; /* Parser state */
         SEAP_scheme_t  scheme; /* Protocol/Scheme used for this descriptor */
         void          *scheme_data; /* Protocol/Scheme related data */
 
         SEXP_t *msg_queue;
-        SEXP_t *err_queue;
+	rbt_t  *err_queue;
         SEXP_t *cmd_queue;
 
-        pqueue_t *pck_queue;
+        SEAP_packetq_t pck_queue;
 
         pthread_mutex_t w_lock;
         pthread_mutex_t r_lock;
@@ -99,6 +98,7 @@ static inline int SEAP_desc_trylock (pthread_mutex_t *m)
                 return (0);
         case EINVAL:
                 errno = EINVAL;
+                /* FALLTHROUGH */
         default:
                 return (-1);
         }
