@@ -33,8 +33,8 @@
 
 #include <stdarg.h>
 #include "public/probe-api.h"
-#include "probe-cache.h"
-#include "encache.h"
+#include "probe/ncache.h"
+#include "probe/rcache.h"
 #include "common/util.h"
 
 /**
@@ -48,18 +48,6 @@ struct id_desc_t {
 	int item_id_ctr;	///< id counter
 };
 
-typedef struct {
-	int option;
-	int (*handler)(int, va_list);
-} probe_option_t;
-
-extern SEAP_CTX_t *OSCAP_GSYM(ctx);
-extern int         OSCAP_GSYM(sd);
-extern pcache_t   *OSCAP_GSYM(pcache);
-extern void       *OSCAP_GSYM(probe_arg);
-extern encache_t  *OSCAP_GSYM(encache);
-extern struct id_desc_t OSCAP_GSYM(id_desc);
-
 #define SEAP_LOCK pthread_mutex_lock (&globals.seap_lock)
 #define SEAP_UNLOCK pthread_mutex_unlock (&globals.seap_lock)
 
