@@ -45,16 +45,16 @@
 #include <stdio.h>
 #include <errno.h>
 
+#include <probe/probe.h>
 #include <probe/option.h>
 #include "seap.h"
 #include "probe-api.h"
 #include "probe/entcmp.h"
 #include "alloc.h"
 
-void *probe_init(void)
+int probe_offline_mode_supported()
 {
-  probe_setoption(PROBEOPT_OFFLINE_MODE_SUPPORTED, true);
-  return NULL;
+	return PROBE_OFFLINE_ALL;
 }
 
 int probe_main(probe_ctx *ctx, void *arg)
