@@ -62,6 +62,9 @@ typedef struct {
 
 	probe_option_t *option; /**< probe option handlers */
 	size_t          optcnt; /**< number of defined options */
+	bool offline_mode;
+	int supported_offline_mode;
+	int selected_offline_mode;
 } probe_t;
 
 struct probe_ctx {
@@ -69,18 +72,17 @@ struct probe_ctx {
         SEXP_t         *probe_out; /**< collected object */
         SEXP_t         *filters;   /**< object filters (OVAL 5.8 and higher) */
         probe_icache_t *icache;    /**< item cache */
+	int offline_mode;
 };
 
 typedef enum {
 	PROBE_OFFLINE_NONE = 0x00,
 	PROBE_OFFLINE_CHROOT = 0x01,
 	PROBE_OFFLINE_RPMDB = 0x02,
+	PROBE_OFFLINE_OWN = 0x04,
 	PROBE_OFFLINE_ALL = 0x0f
 } probe_offline_flags;
 
 extern pthread_barrier_t OSCAP_GSYM(th_barrier);
-extern probe_offline_flags OSCAP_GSYM(offline_mode);
-extern probe_offline_flags OSCAP_GSYM(offline_mode_supported);
-extern int OSCAP_GSYM(offline_mode_cobjflag);
 
 #endif /* PROBE_H */
