@@ -55,6 +55,8 @@
 #include <probe-api.h>
 #include <alloc.h>
 
+#include "common/debug_priv.h"
+#include "public/oval_schema_version.h"
 
 #include "dpkginfo-helper.h"
 
@@ -86,12 +88,17 @@ void probe_fini (void *ptr)
 
 int probe_main (probe_ctx *ctx, void *arg)
 {
-        SEXP_t *val, *item, *ent;
+	SEXP_t *val, *item, *ent, *obj;
         char *request_st = NULL;
         struct dpkginfo_reply_t *dpkginfo_reply = NULL;
         int errflag;
 
-        ent = probe_obj_getent(probe_ctx_getobject(ctx), "name", 1);
+	if (arg == NULL) {
+		return PROBE_EINIT;
+	}
+
+	obj = probe_ctx_getobject(ctx);
+	ent = probe_obj_getent(obj, "name", 1);
 
         if (ent == NULL) {
                 return (PROBE_ENOENT);
@@ -100,7 +107,7 @@ int probe_main (probe_ctx *ctx, void *arg)
         val = probe_ent_getval (ent);
 
         if (val == NULL) {
-                _D("%s: no value\n", "name");
+                dI("%s: no value", "name");
                 SEXP_free (ent);
                 return (PROBE_ENOVAL);
         }
@@ -111,11 +118,11 @@ int probe_main (probe_ctx *ctx, void *arg)
         if (request_st == NULL) {
                 switch (errno) {
                 case EINVAL:
-                        _D("%s: invalid value type\n", "name");
+                        dI("%s: invalid value type", "name");
 			return PROBE_EINVAL;
                         break;
                 case EFAULT:
-                        _D("%s: element not found\n", "name");
+                        dI("%s: element not found", "name");
 			return PROBE_ENOELM;
                         break;
 		default:
@@ -132,12 +139,12 @@ int probe_main (probe_ctx *ctx, void *arg)
                 switch (errflag) {
 		case 0: /* Not found */
 		{
-			_D("Package \"%s\" not found.\n", request_st);
+			dI("Package \"%s\" not found.", request_st);
 			break;
 		}
 		case -1: /* Error */
 		{
-			_D("dpkginfo_get_by_name failed.\n");
+			dI("dpkginfo_get_by_name failed.");
 			item = probe_item_create(OVAL_LINUX_DPKG_INFO, NULL,
 					"name", OVAL_DATATYPE_STRING, request_st,
 					NULL);
@@ -149,16 +156,23 @@ int probe_main (probe_ctx *ctx, void *arg)
         } else { /* Ok */
                 int i;
                 int num_items = 1; /* FIXME */
+		oval_datatype_t evr_string_type;
+		oval_schema_version_t oval_version = probe_obj_get_platform_schema_version(obj);
+		if (oval_schema_version_cmp(oval_version, OVAL_SCHEMA_VERSION(5.11.1)) >= 0) {
+			evr_string_type = OVAL_DATATYPE_DEBIAN_EVR_STRING;
+		} else {
+			evr_string_type = OVAL_DATATYPE_EVR_STRING;
+		}
 
                 for (i = 0; i < num_items; ++i) {
-                        _D("%s: element found version %s\n", dpkginfo_reply->name, dpkginfo_reply->evr);
+                        dI("%s: element found version %s", dpkginfo_reply->name, dpkginfo_reply->evr);
                         item = probe_item_create (OVAL_LINUX_DPKG_INFO, NULL,
                                         "name", OVAL_DATATYPE_STRING, dpkginfo_reply->name,
                                         "arch", OVAL_DATATYPE_STRING, dpkginfo_reply->arch,
                                         "epoch", OVAL_DATATYPE_STRING, dpkginfo_reply->epoch,
                                         "release", OVAL_DATATYPE_STRING, dpkginfo_reply->release,
                                         "version", OVAL_DATATYPE_STRING, dpkginfo_reply->version,
-                                        "evr", OVAL_DATATYPE_EVR_STRING, dpkginfo_reply->evr,
+					"evr", evr_string_type, dpkginfo_reply->evr,
                                         NULL);
 
 			probe_item_collect(ctx, item);
@@ -168,7 +182,7 @@ int probe_main (probe_ctx *ctx, void *arg)
         }
 
         SEXP_vfree(ent, NULL);
-        oscap_free(request_st);
+        free(request_st);
 
         return (0);
 }
