@@ -309,9 +309,10 @@ void probe_preload ()
 	rpmLibsPreload();
 }
 
-void probe_offline_mode ()
+int probe_offline_mode_supported()
 {
-	probe_setoption(PROBEOPT_OFFLINE_MODE_SUPPORTED, PROBE_OFFLINE_OWN);
+	// TODO: Switch this to OFFLINE_MODE_OWN once rpmtsSetRootDir is fully supported by librpm
+	return PROBE_OFFLINE_CHROOT;
 }
 
 void *probe_init (void)
@@ -328,11 +329,6 @@ void *probe_init (void)
 
 	pthread_mutex_init(&(g_rpm.mutex), NULL);
 
-	if (OSCAP_GSYM(offline_mode) & PROBE_OFFLINE_OWN) {
-		const char* root = getenv("OSCAP_PROBE_ROOT");
-		rpmtsSetRootDir(g_rpm.rpmts, root);
-	}
-
 	return ((void *)&g_rpm);
 }
 
@@ -456,6 +452,11 @@ int probe_main (probe_ctx *ctx, void *arg)
 		return 0;
 	}
 
+	if (ctx->offline_mode & PROBE_OFFLINE_OWN) {
+		const char* root = getenv("OSCAP_PROBE_ROOT");
+		rpmtsSetRootDir(g_rpm.rpmts, root);
+	}
+
 	/*
 	 * Get refs to object entities
 	 */
