@@ -452,10 +452,9 @@ static int get_runlevel (struct runlevel_req *req, struct runlevel_rep **rep)
 # error "Sorry, your OS isn't supported."
 #endif
 
-void *probe_init(void)
+int probe_offline_mode_supported()
 {
-  probe_setoption(PROBEOPT_OFFLINE_MODE_SUPPORTED, PROBE_OFFLINE_CHROOT);
-  return NULL;
+	return PROBE_OFFLINE_CHROOT;
 }
 
 int probe_main (probe_ctx *ctx, void *arg)
