@@ -209,13 +209,6 @@ static int read_shadow(SEXP_t *un_ent, probe_ctx *ctx)
 	return err;
 }
 
-void *probe_init(void)
-{
-	// Intentionally commented-out, see commit message
-	// probe_setoption(PROBEOPT_OFFLINE_MODE_SUPPORTED, PROBE_OFFLINE_CHROOT);
-	return (NULL);
-}
-
 int probe_main(probe_ctx *ctx, void *arg)
 {
 	SEXP_t *ent, *obj;
