@@ -47,6 +47,7 @@
 #include <arpa/inet.h>
 #include <regex.h>
 #include <sys/systeminfo.h>
+#include "../../../../common/debug_priv.h"
 
 /* man sysinfo (2) recommends using 257 for this size */
 #define MAX_STR_RESULT 257
@@ -92,8 +93,12 @@ int read_sysinfo(probe_ctx *ctx) {
 	if (sysinfo(SI_ARCHITECTURE_K, result.kernel_isa, MAX_STR_RESULT) == -1) {
 		return err;
 	}
-
+#if defined(__SVR4) && defined(__sun)
+	if ((sysinfo(SI_ARCHITECTURE_32, result.application_isa, MAX_STR_RESULT) == -1) &&
+	   (sysinfo(SI_ARCHITECTURE_64, result.application_isa, MAX_STR_RESULT) == -1)) {
+#else
 	if (sysinfo(SI_ARCHITECTURE_NATIVE, result.application_isa, MAX_STR_RESULT) == -1) {
+#endif
 		return err;
 	}
 
