@@ -55,7 +55,7 @@ typedef struct oval_result_definition {
 
 struct oval_result_definition *oval_result_definition_new(struct oval_result_system *sys, char *definition_id) {
 	oval_result_definition_t *definition = (oval_result_definition_t *)
-	    oscap_alloc(sizeof(oval_result_definition_t));
+	    malloc(sizeof(oval_result_definition_t));
 	if (definition == NULL)
 		return NULL;
 
@@ -110,7 +110,7 @@ void oval_result_definition_free(struct oval_result_definition *definition)
 	definition->messages = NULL;
 	definition->result = OVAL_RESULT_NOT_EVALUATED;
 	definition->instance = 1;
-	oscap_free(definition);
+	free(definition);
 }
 
 struct oval_result_definition *make_result_definition_from_oval_definition
@@ -147,13 +147,20 @@ int oval_result_definition_get_instance(const struct oval_result_definition *def
 oval_result_t oval_result_definition_eval(struct oval_result_definition * definition)
 {
 	__attribute__nonnull__(definition);
+	const char *id = oval_result_definition_get_id(definition);
+	const char *title = oval_definition_get_title(oval_result_definition_get_definition(definition));
+	dI("Evaluating definition '%s': %s.", id, title);
 
 	if (definition->result == OVAL_RESULT_NOT_EVALUATED) {
 		struct oval_result_criteria_node *criteria = oval_result_definition_get_criteria(definition);
-
-		definition->result = (criteria == NULL)
-		    ? OVAL_RESULT_ERROR : oval_result_criteria_node_eval(criteria);
+		if (criteria != NULL) {
+			dIndent(1);
+			definition->result = oval_result_criteria_node_eval(criteria);
+			dIndent(-1);
+		}
 	}
+
+	dI("Definition '%s' evaluated as %s.", id, oval_result_get_text(definition->result));
 	return definition->result;
 }
 
@@ -230,7 +237,7 @@ static int oval_result_definition_parse(xmlTextReaderPtr reader, struct oval_par
 		return_code = oval_message_parse_tag
 		    (reader, context, (oscap_consumer_func) _oval_result_definition_consume_message, usr);
 	}
-	oscap_free(localName);
+	free(localName);
 	return return_code;
 }
 
@@ -275,8 +282,8 @@ int oval_result_definition_parse_tag(xmlTextReaderPtr reader, struct oval_parser
 
 	return_code = oval_parser_parse_tag(reader, context, oval_result_definition_parse, definition);
 
-	oscap_free(definition_id);
-	oscap_free(definition_version);
+	free(definition_id);
+	free(definition_version);
 
 	return return_code;
 }
