@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2014--2016 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -69,6 +69,10 @@ bool xccdf_policy_model_item_is_applicable(struct xccdf_policy_model *model, str
  */
 struct cpe_session *xccdf_policy_model_get_cpe_session(struct xccdf_policy_model *model);
 
+struct xccdf_policy *xccdf_policy_model_get_existing_policy_by_id(struct xccdf_policy_model *policy_model, const char *profile_id);
+
+struct xccdf_policy *xccdf_policy_model_create_policy_by_id(struct xccdf_policy_model *policy_model, const char *id);
+
 OSCAP_HIDDEN_END;
 
 #endif
