@@ -60,6 +60,8 @@ struct xccdf_policy {
 	struct xccdf_policy_model   * model;    ///< XCCDF Policy model
 	struct xccdf_profile        * profile;  ///< Profile structure (from benchmark)
 	/** A list of all selects. Either from profile or later added through API. */
+	const char *rule;			///< Single-rule feature: if not NULL, only this one rule will be selected.
+	int rule_found;				///< Single-rule feature: flag for rule - if rule is found it is set to 1 otherwise 0.
 	struct oscap_list           * selects;
 	struct oscap_list           * values;   ///< Bound values of profile
 	struct oscap_list           * results;  ///< List of XCCDF results
