@@ -57,29 +57,29 @@ OSCAP_ITERATOR_GEN(oscap_reference)
 
 struct oscap_reference *oscap_reference_new(void)
 {
-    return oscap_calloc(1, sizeof(struct oscap_reference));
+    return calloc(1, sizeof(struct oscap_reference));
 }
 
 void oscap_reference_free(struct oscap_reference *ref)
 {
     if (ref) {
-        oscap_free(ref->title);
-        oscap_free(ref->creator);
-        oscap_free(ref->subject);
-        oscap_free(ref->description);
-        oscap_free(ref->publisher);
-        oscap_free(ref->contributor);
-        oscap_free(ref->date);
-        oscap_free(ref->type);
-        oscap_free(ref->format);
-        oscap_free(ref->identifier);
-        oscap_free(ref->source);
-        oscap_free(ref->language);
-        oscap_free(ref->relation);
-        oscap_free(ref->coverage);
-        oscap_free(ref->rights);
-        oscap_free(ref->href);
-        oscap_free(ref);
+        free(ref->title);
+        free(ref->creator);
+        free(ref->subject);
+        free(ref->description);
+        free(ref->publisher);
+        free(ref->contributor);
+        free(ref->date);
+        free(ref->type);
+        free(ref->format);
+        free(ref->identifier);
+        free(ref->source);
+        free(ref->language);
+        free(ref->relation);
+        free(ref->coverage);
+        free(ref->rights);
+        free(ref->href);
+        free(ref);
     }
 }
 
@@ -133,7 +133,7 @@ struct oscap_reference *oscap_reference_new_parse(xmlTextReaderPtr reader)
 {
     assert(reader != NULL);
 
-    struct oscap_reference *ref = oscap_calloc(1, sizeof(struct oscap_reference));
+    struct oscap_reference *ref = calloc(1, sizeof(struct oscap_reference));
 
     int depth = oscap_element_depth(reader);
 
