@@ -17,9 +17,11 @@ name=$(basename $0 .sh)
 stderr=$(mktemp -t ${name}.err.XXXXXX)
 echo "Stderr file = $stderr"
 
-$OSCAP info ${srcdir}/${name}.xccdf.xml 2> $stderr
+ret=0
+$OSCAP info ${srcdir}/${name}.xccdf.xml 2> $stderr || ret=$?
+[ $ret -eq 1 ]
 [ -f $stderr ]
 [ -s $stderr ]
-cat $stderr | head -n 1 | grep '^OpenSCAP Error:'
+cat $stderr | tail -n +1 | grep '^OpenSCAP Error:'
 
 rm $stderr
