@@ -1,7 +1,13 @@
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <string.h>
 #include <stdlib.h>
 #include <seap.h>
 #include <probe-api.h>
+#include "common/memusage.h"
 
 #define FAIL(ret, ...)                                        \
         do {                                                  \
@@ -11,7 +17,7 @@
 
 #define WARN(...) fprintf (stderr, "WARN: " __VA_ARGS__)
 
-void print_asdf (SEXP_t *asdf)
+static void print_asdf (SEXP_t *asdf)
 {
         (void) SEXP_fprintfa (stdout, asdf);
         (void) fputc ('\n', stdout);
@@ -479,6 +485,159 @@ int main (void)
         }
 
         SEXP_free (obj);
-        
+
+        {
+	        struct test {
+		        oval_datatype_t t;
+		        const char     *v;
+	        } __test_array[] = {
+		        { OVAL_DATATYPE_FLOAT,   "1.2345" },
+		        { OVAL_DATATYPE_INTEGER, "12345" },
+		        { OVAL_DATATYPE_BOOLEAN, "1" },
+		        { OVAL_DATATYPE_BOOLEAN, "0" },
+		        { OVAL_DATATYPE_BOOLEAN, "true" },
+		        { OVAL_DATATYPE_BOOLEAN, "false" },
+		        { OVAL_DATATYPE_IPV4ADDR, "192.168.0.1" },
+		        { OVAL_DATATYPE_IPV6ADDR, "fe80::f2de:f1ff:fe6a:13fd" },
+		        { OVAL_DATATYPE_EVR_STRING, "1.7.2p1" },
+		        { OVAL_DATATYPE_FILESET_REVISION, "12345" },
+		        { OVAL_DATATYPE_IOS_VERSION, "1234" },
+		        { OVAL_DATATYPE_STRING, "Hello world!" },
+		        { OVAL_DATATYPE_VERSION, "1.7.2p1" }
+	        };
+
+	        for (unsigned int i = 0;
+	             i < sizeof __test_array/(sizeof(struct test)); ++i)
+		        {
+			        ent = probe_ent_from_cstr("test",
+			                                  __test_array[i].t,
+			                                  __test_array[i].v,
+			                                  strlen(__test_array[i].v));
+			        if (ent == NULL)
+				        FAIL(1, "probe_ent_from_cstr(%s, %d, %s, %zu) == NULL\n",
+				             "test", __test_array[i].t,
+				             __test_array[i].v,
+				             strlen(__test_array[i].v));
+			        print_asdf(ent);
+			        SEXP_free(ent);
+		        }
+        }
+
+        {
+	        struct sys_memusage mu_sys;
+	        struct proc_memusage mu_proc;
+
+	        if (oscap_sys_memusage(&mu_sys) != 0)
+		        FAIL(1, "oscap_sys_memusage != 0\n");
+	        if (oscap_proc_memusage(&mu_proc) != 0)
+		        FAIL(1, "oscap_proc_memusage != 0\n");
+
+	        printf("mu_sys:\n"
+	               "   mu_active: %zu\n"
+	               "  mu_buffers: %zu\n"
+	               "   mu_cached: %zu\n"
+	               " mu_inactive: %zu\n"
+	               "     mu_free: %zu\n"
+	               "    mu_total: %zu\n"
+	               " mu_realfree: %zu\n",
+	               mu_sys.mu_active,
+	               mu_sys.mu_buffers,
+	               mu_sys.mu_cached,
+	               mu_sys.mu_inactive,
+	               mu_sys.mu_free,
+	               mu_sys.mu_total,
+	               mu_sys.mu_realfree);
+
+	        printf("mu_proc:\n"
+	               "  mu_data: %zu\n"
+	               "  mu_text: %zu\n"
+	               "   mu_hwm: %zu\n"
+	               "  mu_lock: %zu\n"
+	               "   mu_lib: %zu\n"
+	               "   mu_rss: %zu\n"
+	               " mu_stack: %zu\n",
+	               mu_proc.mu_data,
+	               mu_proc.mu_text,
+	               mu_proc.mu_hwm,
+	               mu_proc.mu_lock,
+	               mu_proc.mu_lib,
+	               mu_proc.mu_rss,
+	               mu_proc.mu_stack);
+        }
+
+        /*
+         * ((test_object :attr1 123) ((ent1 :entattr1 456) "abc"))
+         */
+
+        {
+            SEXP_t *a1val, *e1a1val, *e1val, *oatt, *e1att;
+
+            a1val = SEXP_number_newu_8 (123);
+            e1a1val = SEXP_number_newu_16 (456);
+            e1val = SEXP_string_newf ("abc");
+
+            oatt  = probe_attr_creat ("attr1", a1val, NULL);
+            e1att = probe_attr_creat ("entattr1", e1a1val, NULL);
+
+            obj = probe_obj_creat ("test_object", oatt,
+                                   "ent1", e1att, e1val,
+                                   NULL);
+
+            SEXP_free (a1val);
+            SEXP_free (e1a1val);
+            SEXP_free (e1val);
+            SEXP_free (oatt);
+            SEXP_free (e1att);
+        }
+
+        print_asdf (obj);
+
+        {
+            ent = probe_obj_getent(obj, "ent1", 1);
+            if (ent == NULL)
+               FAIL(1, "`ent1' not found!\n");
+            if (probe_ent_attrexists(ent, "mask"))
+                FAIL(1, "`mask' attribute found in obj!");
+            SEXP_free(ent);
+        }
+        SEXP_free(obj);
+
+        /*
+         * ((test_object :attr1 123) ((ent1 :entattr1 456 mask :attr2 345) "abc"))
+         */
+
+        {
+            SEXP_t *a1val, *e1a1val, *e1val, *oatt, *e1att;
+
+            a1val = SEXP_number_newu_8 (123);
+            e1a1val = SEXP_number_newu_16 (456);
+            e1val = SEXP_string_newf ("abc");
+
+            oatt  = probe_attr_creat ("attr1", a1val, NULL);
+            e1att = probe_attr_creat ("entattr1", e1a1val, "mask", NULL, "attr2", e1a1val, NULL);
+
+            obj = probe_obj_creat ("test_object", oatt,
+                                   "ent1", e1att, e1val,
+                                   NULL);
+
+            SEXP_free (a1val);
+            SEXP_free (e1a1val);
+            SEXP_free (e1val);
+            SEXP_free (oatt);
+            SEXP_free (e1att);
+        }
+
+        print_asdf (obj);
+
+        {
+            ent = probe_obj_getent(obj, "ent1", 1);
+            if (ent == NULL)
+                FAIL(1, "`ent1' not found!\n");
+            if (!probe_ent_attrexists(ent, "mask"))
+                FAIL(1, "`mask' attribute not found in obj!\n");
+            SEXP_free(ent);
+        }
+        SEXP_free(obj);
+
         return (0);
 }
