@@ -12,7 +12,7 @@
 #      David Niemoller
 #      Ondrej Moris, <omoris@redhat.com>
 
-. ${srcdir}/../../test_common.sh
+. ../../test_common.sh
 
 # Test Cases.
 
@@ -72,6 +72,8 @@ function test_probes_sysinfo {
 
 test_init "test_probes_sysinfo.log"
 
-test_run "test_probes_sysinfo" test_probes_sysinfo
+if [ -z ${CUSTOM_OSCAP+x} ] ; then
+    test_run "test_probes_sysinfo" test_probes_sysinfo
+fi
 
 test_exit
