@@ -1,8 +1,26 @@
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #define XINETD_TEST
 #include <../../../../src/OVAL/probes/unix/xinetd.c>
 
 #define EMPTYSTR_IF_NULL(val) val ? val : ""
 
+static char *string_array_cstr(char **string_array)
+{
+	char buf[8192]; // Ought to be enough for anybody
+	size_t string_array_pos, bufpos = 0;
+	buf[0] = '\0';
+	if (string_array != NULL) {
+		for (string_array_pos = 0; string_array[string_array_pos] && (sizeof(buf) - bufpos - 1) > 1; ++string_array_pos) {
+			bufpos += snprintf(buf + bufpos, sizeof(buf) - bufpos - 1, "%s ", string_array[string_array_pos]);
+		}
+	}
+	return strdup(buf);
+}
+
 int main (int argc, char *argv[])
 {
 	xiconf_t         *xcfg;
@@ -54,15 +72,15 @@ int main (int argc, char *argv[])
 				"  def_enabled: %d\n",
 				EMPTYSTR_IF_NULL(xres->srv[l]->id),
 				EMPTYSTR_IF_NULL(xres->srv[l]->type),
-				EMPTYSTR_IF_NULL(xres->srv[l]->flags),
+				string_array_cstr(xres->srv[l]->flags),
 				EMPTYSTR_IF_NULL(xres->srv[l]->socket_type),
 				EMPTYSTR_IF_NULL(xres->srv[l]->name),
 				EMPTYSTR_IF_NULL(xres->srv[l]->protocol),
 				EMPTYSTR_IF_NULL(xres->srv[l]->user),
 				EMPTYSTR_IF_NULL(xres->srv[l]->server),
 				EMPTYSTR_IF_NULL(xres->srv[l]->server_args),
-				EMPTYSTR_IF_NULL(xres->srv[l]->only_from),
-				EMPTYSTR_IF_NULL(xres->srv[l]->no_access),
+				string_array_cstr(xres->srv[l]->only_from),
+				string_array_cstr(xres->srv[l]->no_access),
 				xres->srv[l]->port,
 				xres->srv[l]->disable,
 				xres->srv[l]->wait,
