@@ -8,7 +8,7 @@
 
 set -e -o pipefail
 
-. ${srcdir}/../test_common.sh
+. ../test_common.sh
 
 # Test Cases.
 function test_passing_values {
