@@ -37,9 +37,11 @@
 #include <oval_probe.h>
 #include <cvss_score.h>
 #include <xccdf_benchmark.h>
+#include <xccdf_session.h>
 #include <cpe_dict.h>
 #include <cpe_name.h>
 #include <cve_nvd.h>
+#include <cvrf.h>
 
 #define OSCAP_PRODUCTNAME "cpe:/a:open-scap:oscap"
 #define OSCAP_ERR_MSG "OpenSCAP Error:"
@@ -98,6 +100,13 @@ struct cve_action {
         char * cve;
 };
 
+struct cvrf_action {
+	int index;
+	char *f_cvrf;
+	char *f_results;
+	char *f_output;
+};
+
 struct oscap_action {
         struct oscap_module *module;
 	/* files */
@@ -112,6 +121,7 @@ struct oscap_action {
 	char *f_syschar;
 	char *f_directives;
         char *f_results;
+	char *f_results_stig;
 	char *f_results_arf;
         char *f_report;
 	char *f_variables;
@@ -135,10 +145,13 @@ struct oscap_action {
 	struct ds_action* ds_action;
 	struct cpe_action * cpe_action;
 	struct cve_action * cve_action;
+	struct cvrf_action * cvrf_action;
 	char *file;
 
 	int verbosity;
-        int doctype;
+	int show_profiles_only;
+	int provide_machine_readable_output;
+	int doctype;
 	int force;
 	int validate;
 	int schematron;
@@ -168,12 +181,16 @@ void oscap_print_error(void);
 bool check_verbose_options(struct oscap_action *action);
 void download_reporting_callback(bool warning, const char *format, ...);
 
+
+int xccdf_set_profile_or_report_bad_id(struct xccdf_session *session, const char *profile_id, const char *source_file);
+
 extern struct oscap_module OSCAP_ROOT_MODULE;
 extern struct oscap_module OSCAP_DS_MODULE;
 extern struct oscap_module OSCAP_XCCDF_MODULE;
 extern struct oscap_module OSCAP_CVSS_MODULE;
 extern struct oscap_module OSCAP_OVAL_MODULE;
 extern struct oscap_module OSCAP_CVE_MODULE;
+extern struct oscap_module OSCAP_CVRF_MODULE;
 extern struct oscap_module OSCAP_CPE_MODULE;
 extern struct oscap_module OSCAP_INFO_MODULE;
 
